Database push / pull: serialise the user, skill, and context tables to
JSON and round-trip them between a local Postgres and a cloud Postgres
using compile-time-checked sqlx upserts.
Database push / pull: serialise the user, skill, and context tables to
JSON and round-trip them between a local Postgres and a cloud Postgres
using compile-time-checked sqlx upserts.